@@ -6,19 +6,19 @@ import qualified Data.ByteString as B
 import qualified Data.ByteString.Lazy.Builder as BB
 import qualified Data.ByteString.Lazy.Builder.ASCII as BB
 import qualified Data.ByteString.Lazy as BL
-import qualified Data.Text as T
-import qualified Data.Text.Encoding as TE
 
 
+-- |
+-- Connection settings.
 data Settings =
-  Settings {
-    host :: ByteString,
-    port :: Word16,
-    user :: Text,
-    password :: Text,
-    database :: Text
-  }
-
+  -- | 
+  -- A host, a port, a user, a password and a database.
+  ParamSettings ByteString Word16 ByteString ByteString ByteString |
+  -- | 
+  -- All settings encoded in a single byte string according to 
+  -- <http://www.postgresql.org/docs/9.4/static/libpq-connect.html#LIBPQ-CONNSTRING the PostgreSQL format>.
+  StringSettings ByteString
+  deriving (Show)
 
 data Error =
   BadStatus (Maybe ByteString) |
@@ -49,22 +49,25 @@ open s =
 
 
 settingsBS :: Settings -> ByteString
-settingsBS s =
-  BL.toStrict $ BB.toLazyByteString $ mconcat $ intersperse (BB.char7 ' ') $ catMaybes $
-  [
-    mappend (BB.string7 "host=") . BB.byteString <$> 
-    partial (not . B.null) (host s)
-    ,
-    mappend (BB.string7 "port=") . BB.word16Dec <$> 
-    partial (/= 0) (port s)
-    ,
-    mappend (BB.string7 "user=") . BB.byteString . TE.encodeUtf8 <$> 
-    partial (not . T.null) (user s)
-    ,
-    mappend (BB.string7 "password=") . BB.byteString . TE.encodeUtf8 <$> 
-    partial (not . T.null) (password s)
-    ,
-    mappend (BB.string7 "dbname=") . BB.byteString . TE.encodeUtf8 <$> 
-    partial (not . T.null) (database s)
-  ]
+settingsBS =
+  \case
+    ParamSettings host port user password database ->
+      BL.toStrict $ BB.toLazyByteString $ mconcat $ intersperse (BB.char7 ' ') $ catMaybes $
+      [
+        mappend (BB.string7 "host=") . BB.byteString <$> 
+        partial (not . B.null) host
+        ,
+        mappend (BB.string7 "port=") . BB.word16Dec <$> 
+        partial (/= 0) port
+        ,
+        mappend (BB.string7 "user=") . BB.byteString <$> 
+        partial (not . B.null) user
+        ,
+        mappend (BB.string7 "password=") . BB.byteString <$> 
+        partial (not . B.null) password
+        ,
+        mappend (BB.string7 "dbname=") . BB.byteString <$> 
+        partial (not . B.null) database
+      ]
+    StringSettings x -> x
 
